#-*- coding: utf-8 -*-

from django import forms
from django.contrib.auth.forms import AuthenticationForm
from django.contrib.auth.models import User

from django.utils.translation import ugettext as _
from django.contrib.admin import widgets


class ConnexionForm(forms.Form):
    username = forms.CharField(required=True, max_length=20, label="Login")
    password = forms.CharField(required=True, max_length=20, label=("Mot de passe"), widget=forms.PasswordInput())


CHOICES_DEPOT= (
('NODEPOT', 'Pas de dépôt'),
('PREPROD', 'Dépôt préprod'),
('PRODHAL', 'Dépôt HAL'),
)

CHOICES_SOURCE_BIBTEX = (
('DBLP','DBLP'),
('ENDNOTE','ENDNOTE'),    
)

CHOICES_SOURCE_CSV = (
('PUBMED','PUBMED'),     
#('SCOPUS','SCOPUS'), 
)

CHOICES_SOURCE_TEXT = (
('RG','Research Gate'),     
)

class Bibtex2halForm(forms.Form): 
    bib_name_user = forms.CharField(required=True, max_length=40, label="Forme auteur Bibtex (*)")
    name_user = forms.CharField(required=True, max_length=40, label="Nom chercheur (*)")
    firstname_user = forms.CharField(required=True, max_length=40, label="Prénom chercheur (*)")
    labo_auth_final = forms.CharField(required=True, max_length=40, label="N° de structure (*) (Ex: 490706)", initial = 490706)   
    id_hal_user = forms.CharField(required=True, max_length=40, label="IdHal chercheur (*)")
    login_user = forms.CharField(required=True, max_length=40, label="Login HAL chercheur (*)")
    
    choice_source = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES_SOURCE_BIBTEX, label="Choix de la source", initial='DBLP' )

    login_depot = forms.CharField(required=True, max_length=40, label="Login HAL référent (*)")
    passwd_depot = forms.CharField(required=True, max_length=40, label=("Password HAL référent (*)"), widget=forms.PasswordInput())
    choice_depot = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES_DEPOT, label="Choix du dépôt", initial='NODEPOT' )
 
    domain1 = forms.CharField(required=True, max_length=20, label="Domaine 1 (*)")
    domain2 = forms.CharField(required=False, max_length=20, label="Domaine 2")
    domain3 = forms.CharField(required=False, max_length=20, label="Domaine 3")
    domain4 = forms.CharField(required=False, max_length=20, label="Domaine 4")
    domain5 = forms.CharField(required=False, max_length=20, label="Domaine 5")

    bibtex_file = forms.CharField(required=True, label="contenu bibtex", widget=forms.Textarea(attrs={'rows':20, 'cols':90}),)


class BibtexXmlForm(forms.Form): 
    bib_name_user = forms.CharField(required=True, max_length=40, label="Forme auteur DBLP (*)")
    name_user = forms.CharField(required=True, max_length=40, label="Nom chercheur (*)")
    firstname_user = forms.CharField(required=True, max_length=40, label="Prénom chercheur (*)")
    labo_auth_final = forms.CharField(required=True, max_length=40, label="N° de structure (*) (Ex: 490706)", initial = 490706)   
    id_hal_user = forms.CharField(required=True, max_length=40, label="IdHal chercheur (*)")
    login_user = forms.CharField(required=True, max_length=40, label="Login HAL chercheur (*)")

    choice_source = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES_SOURCE_BIBTEX, label="Choix de la source", initial='DBLP' )

    domain1 = forms.CharField(required=True, max_length=20, label="Domaine 1 (*)")
    domain2 = forms.CharField(required=False, max_length=20, label="Domaine 2")
    domain3 = forms.CharField(required=False, max_length=20, label="Domaine 3")
    domain4 = forms.CharField(required=False, max_length=20, label="Domaine 4")
    domain5 = forms.CharField(required=False, max_length=20, label="Domaine 5")

    bibtex_file = forms.CharField(required=True, label="contenu bibtex", widget=forms.Textarea(attrs={'rows':20, 'cols':90}),)

class Csv2halForm(forms.Form):
    form_author = forms.CharField(required=True, max_length=40, label="Forme auteur (*)")
    name_user = forms.CharField(required=True, max_length=40, label="Nom chercheur (*)")
    firstname_user = forms.CharField(required=True, max_length=40, label="Prénom chercheur (*)")
    labo_auth_final = forms.CharField(required=True, max_length=40, label="N° de structure (*) (Ex: 490706)")   
    id_hal_user = forms.CharField(required=True, max_length=40, label="IdHal chercheur (*)")
    login_user = forms.CharField(required=True, max_length=40, label="Login HAL chercheur (*)")

    choice_source = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES_SOURCE_CSV, label="Choix de la source", initial='PUBMED' )
   
    login_depot = forms.CharField(required=True, max_length=40, label="Login HAL référent (*)")
    passwd_depot = forms.CharField(required=True, max_length=40, label=("Password HAL référent (*)"), widget=forms.PasswordInput())
    choice_depot = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES_DEPOT, label="Choix du dépôt", initial='NODEPOT' )

    domain1 = forms.CharField(required=True, max_length=20, label="Domaine 1 (*)")
    domain2 = forms.CharField(required=False, max_length=20, label="Domaine 2")
    domain3 = forms.CharField(required=False, max_length=20, label="Domaine 3")
    domain4 = forms.CharField(required=False, max_length=20, label="Domaine 4")
    domain5 = forms.CharField(required=False, max_length=20, label="Domaine 5")

    csv_file = forms.CharField(required=True, label="contenu CSV", widget=forms.Textarea(attrs={'rows':20, 'cols':90}),)


class Text2halForm(forms.Form): 
    form_author = forms.CharField(required=True, max_length=40, label="Forme auteur (*)")
    name_user = forms.CharField(required=True, max_length=40, label="Nom chercheur (*)")
    firstname_user = forms.CharField(required=True, max_length=40, label="Prénom chercheur (*)")
    labo_auth_final = forms.CharField(required=True, max_length=40, label="N° de structure (*) (Ex: 490706)")   
    id_hal_user = forms.CharField(required=True, max_length=40, label="IdHal chercheur (*)")
    login_user = forms.CharField(required=True, max_length=40, label="Login HAL chercheur (*)")
    
    login_depot = forms.CharField(required=True, max_length=40, label="Login HAL référent (*)")
    passwd_depot = forms.CharField(required=True, max_length=40, label=("Password HAL référent (*)"), widget=forms.PasswordInput())
    choice_depot = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES_DEPOT, label="Choix du dépôt", initial='NODEPOT' )

    domain1 = forms.CharField(required=True, max_length=20, label="Domaine 1 (*)")
    domain2 = forms.CharField(required=False, max_length=20, label="Domaine 2")
    domain3 = forms.CharField(required=False, max_length=20, label="Domaine 3")
    domain4 = forms.CharField(required=False, max_length=20, label="Domaine 4")
    domain5 = forms.CharField(required=False, max_length=20, label="Domaine 5")

    text_file = forms.CharField(required=True, label="contenu texte", widget=forms.Textarea(attrs={'rows':20, 'cols':90}),)


class TextXmlForm(forms.Form): 
    form_author = forms.CharField(required=True, max_length=40, label="Forme auteur (*)")
    name_user = forms.CharField(required=True, max_length=40, label="Nom chercheur (*)")
    firstname_user = forms.CharField(required=True, max_length=40, label="Prénom chercheur (*)")
    labo_auth_final = forms.CharField(required=True, max_length=40, label="N° de structure (*) (Ex: 490706)")   
    id_hal_user = forms.CharField(required=True, max_length=40, label="IdHal chercheur (*)")
    login_user = forms.CharField(required=True, max_length=40, label="Login HAL chercheur (*)")

    domain1 = forms.CharField(required=True, max_length=20, label="Domaine 1 (*)")
    domain2 = forms.CharField(required=False, max_length=20, label="Domaine 2")
    domain3 = forms.CharField(required=False, max_length=20, label="Domaine 3")
    domain4 = forms.CharField(required=False, max_length=20, label="Domaine 4")
    domain5 = forms.CharField(required=False, max_length=20, label="Domaine 5")

    text_file = forms.CharField(required=True, label="contenu texte", widget=forms.Textarea(attrs={'rows':20, 'cols':90}),)

class ModifTextForm(forms.Form):
    delete_char = forms.IntegerField(required=False, label="Supprimer premiers caracteres", initial = 0)
    add_begin = forms.CharField(required=False, max_length=20, label="Ajouter lettres + chiffre + -")
    clean_text = forms.BooleanField(required=False, label="Nettoyer et formater", initial=False)
    reverse_first_lastname = forms.BooleanField(required=False, label="Inverser nom et prénom", initial=False)
    get_volume = forms.BooleanField(required=False, label="Formater les volumes", initial=False)
    get_pages = forms.BooleanField(required=False, label="Formater les pages", initial=False)
    transform_country = forms.BooleanField(required=False, label="Formater les pays", initial=False)
    text_modif = forms.CharField(required=True, label="contenu texte", widget=forms.Textarea(attrs={'rows':20, 'cols':90}),)

class TextFromRG(forms.Form):
    choice_source = forms.ChoiceField(widget=forms.RadioSelect, choices=CHOICES_SOURCE_TEXT, label="Choix de la source", initial='RG' )    
    text_modif = forms.CharField(required=True, label="contenu texte", widget=forms.Textarea(attrs={'rows':20, 'cols':90}),)


